@@ -24,12 +24,12 @@ func printStatistics(stats map[string]subscraping.Statistics) {
 		if sourceStats.Skipped {
 			skipped = append(skipped, fmt.Sprintf(" %s", source))
 		} else {
-			lines = append(lines, fmt.Sprintf(" %-20s %-10s %10d %10d", source, sourceStats.TimeTaken.Round(time.Millisecond).String(), sourceStats.Results, sourceStats.Errors))
+			lines = append(lines, fmt.Sprintf(" %-20s %-10s %10d %10d %10d", source, sourceStats.TimeTaken.Round(time.Millisecond).String(), sourceStats.Results, sourceStats.Requests, sourceStats.Errors))
 		}
 	}
 
 	if len(lines) > 0 {
-		gologger.Print().Msgf("\n Source               Duration      Results     Errors\n%s\n", strings.Repeat("─", 56))
+		gologger.Print().Msgf("\n Source               Duration      Results   Requests     Errors\n%s\n", strings.Repeat("─", 68))
 		gologger.Print().Msg(strings.Join(lines, "\n"))
 		gologger.Print().Msgf("\n")
 	}
